﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using System.Windows.Resources;
using System.Xml;

namespace IEGeolocMock
{
    public partial class Form1 : Form
    {
        private LocationState locationState = null;
        private bool textBoxIgnoreEvent = false;
        private bool webBrowserIgnoreEvent = false;
        private string logMsgs = "";

        public Form1()
        {
            Fiddler.FiddlerApplication.Log.OnLogString += new EventHandler<Fiddler.LogEventArgs>(Log_OnLogString);
            InitializeComponent();
            this.FormClosing += new FormClosingEventHandler(Form1_FormClosing);

            this.locationState = new LocationState();
            Fiddler.FiddlerApplication.Log.OnLogString += new EventHandler<Fiddler.LogEventArgs>(Log_OnLogString);
            StateToTextBoxes();
            this.locationState.LocationUpdated += new LocationState.LocationUpdatedHandler(locationState_LocationUpdated);

            this.latitudeTextBox.TextChanged += new EventHandler(TextBox_TextChanged);
            this.longitudeTextBox.TextChanged += new EventHandler(TextBox_TextChanged);
            this.altitudeTextBox.TextChanged += new EventHandler(TextBox_TextChanged);
            this.uncertaintyTextBox.TextChanged += new EventHandler(TextBox_TextChanged);

            this.uncertaintyTextBox.KeyPress += new KeyPressEventHandler(uncertaintyTextBox_KeyPress);
        }

        void Log_OnLogString(object sender, Fiddler.LogEventArgs e)
        {
            System.Diagnostics.Debug.WriteLine(e.LogString);
        }

        void uncertaintyTextBox_KeyPress(object sender, KeyPressEventArgs e)
        {
            if (e.KeyChar == 'l')
            {
                MessageBox.Show(this.logMsgs, this.logMsgs);
            }
        }

        void locationState_LocationUpdated(object sender, EventArgs args)
        {
            StateToTextBoxes();
            StateToWebBrowser();
        }

        void TextBox_TextChanged(object sender, EventArgs e)
        {
            TextBoxesToState();
        }

        void Form1_FormClosing(object sender, FormClosingEventArgs e)
        {
            this.locationState.Stop();
            this.locationState = null;

            this.webBrowser2.Dispose();
            this.webBrowser2 = null;
        }

        private void Form1_Load(object sender, EventArgs e)
        {
            this.webBrowser2.Hide();
            try
            {
                this.webBrowser2.ObjectForScripting = this.locationState;
            }
            catch (Exception exception)
            {
                MessageBox.Show(exception.ToString());
            }
            this.webBrowser2.Url = new Uri("http://deletethis.net/dave/dev/geolocmock/locate.html");
            this.webBrowser2.DocumentCompleted += new WebBrowserDocumentCompletedEventHandler(webBrowser2_DocumentCompleted);
            this.webBrowser2.AllowNavigation = false;
        }

        void webBrowser2_DocumentCompleted(object sender, WebBrowserDocumentCompletedEventArgs e)
        {
            StateToWebBrowser();
            this.webBrowser2.Show();
        }

        private void TextBoxesToState()
        {
            this.textBoxIgnoreEvent = true;
            this.locationState.Set(
                this.latitudeTextBox.Text,
                this.longitudeTextBox.Text,
                this.altitudeTextBox.Text,
                this.uncertaintyTextBox.Text);
            this.textBoxIgnoreEvent = false;
        }

        private void StateToWebBrowser()
        {
            if (!this.webBrowserIgnoreEvent)
            {
                string latitudeTextBoxText = null;
                string longitudeTextBoxText = null;
                string altitudeTextBoxText = null;
                string uncertaintyTextBoxText = null;

                this.locationState.Get(
                    out latitudeTextBoxText,
                    out longitudeTextBoxText,
                    out altitudeTextBoxText,
                    out uncertaintyTextBoxText);

                this.webBrowser2.Document.InvokeScript("onLocationStateChanged",
                    new object[] {
                        latitudeTextBoxText,
                        longitudeTextBoxText,
                        altitudeTextBoxText,
                        uncertaintyTextBoxText
                    });
            }
        }

        private void StateToTextBoxes()
        {
            if (!this.textBoxIgnoreEvent)
            {
                string latitudeTextBoxText = null;
                string longitudeTextBoxText = null;
                string altitudeTextBoxText = null;
                string uncertaintyTextBoxText = null;

                this.locationState.Get(
                    out latitudeTextBoxText,
                    out longitudeTextBoxText,
                    out altitudeTextBoxText,
                    out uncertaintyTextBoxText);

                this.latitudeTextBox.Text = latitudeTextBoxText;
                this.longitudeTextBox.Text = longitudeTextBoxText;
                this.altitudeTextBox.Text = altitudeTextBoxText;
                this.uncertaintyTextBox.Text = uncertaintyTextBoxText;
            }
        }

        private void latitudeTextBox_TextChanged(object sender, EventArgs e)
        {

        }

        private void aboutLink_LinkClicked(object sender, LinkLabelLinkClickedEventArgs e)
        {
            System.Diagnostics.Process.Start("http://deletethis.net/dave/dev/geolocmock/?from=app");
        }

        private void tableLayoutPanel1_Paint(object sender, PaintEventArgs e)
        {

        }
    }
}